﻿use strict;
use utf8;

use Test::More;

use DE_EPAGES::Core::API::Password qw(
    CryptPassword
    CheckPassword
    GenerateNewPassword
);

use constant BCRYPT_HASH_LENGTH => 60;

plan tests => 12;

# test generating new passwords
my $GeneratedPassword = GenerateNewPassword(15);
ok($GeneratedPassword =~ m/^[[:alnum:]]{15}$/, 'GenerateNewPassword(15) returns a 15 alphanumeric character long password');

my $AnotherPassword = GenerateNewPassword(15);
isnt($GeneratedPassword, $AnotherPassword, 'two runs of GenerateNewPassword returns different passwords');


# test bcrypt
my $Password = "Äßµü$GeneratedPassword";
my $BcryptPasswordHash = CryptPassword($Password);

ok(($BcryptPasswordHash =~ m/^\$2a\$/ and length($BcryptPasswordHash) == BCRYPT_HASH_LENGTH), 'hashed password is a bcrypt hash');

my $SecondBcryptPasswordHash = CryptPassword($Password);
isnt($SecondBcryptPasswordHash, $BcryptPasswordHash, 'two runs of CryptPassword use different salts');

ok(CheckPassword($Password, $BcryptPasswordHash), 'bcrypt verifies the correct password');
ok(!CheckPassword($AnotherPassword, $BcryptPasswordHash), 'bcrypt doesn\'t verifies an uncorrect password');


# test legacy hashing
my $LegacyPassword = 'ywSx9ODjxzKDAAs';

# DES
my $DESLegacyPasswordHash = 'AAAphD/c9/BnA';

ok(CheckPassword($LegacyPassword, $DESLegacyPasswordHash), 'DES verifies the correct password');
ok(!CheckPassword($AnotherPassword, $DESLegacyPasswordHash), 'DES doesn\'t verifies an uncorrect password');

# MD5
my $MD5LegacyPasswordHash = '$1$tf1FHQyT$gAYMzzhIF/0FbiHA8TxsO0';

ok(CheckPassword($LegacyPassword, $MD5LegacyPasswordHash), 'MD5 verifies the correct password');
ok(!CheckPassword($AnotherPassword, $MD5LegacyPasswordHash), 'MD5 doesn\'t verifies an uncorrect password');

# SHA-256
my $SHA256LegacyPasswordHash = '0b7fec3b2dd9d54e2240539847e57934c8a853f343ec10b388013b8cd07e8052';

ok(CheckPassword($LegacyPassword, $SHA256LegacyPasswordHash), 'SHA verifies the correct password');
ok(!CheckPassword($AnotherPassword, $SHA256LegacyPasswordHash), 'SHA doesn\'t verifies an uncorrect password');
