#========================================================================================
# package      Test
#----------------------------------------------------------------------------------------
# description  Package for testing TrayBuilder.pm
#========================================================================================
package Test;
use parent DE_EPAGES::Database::API::Test;

use strict;
use Test::More tests => 3;
use DE_EPAGES::Presentation::API::Object::TrayBuilder; # requier storedb
use DE_EPAGES::Core::API::Error qw ( ExistsError );

sub test {
    my $self       = shift;
    my $LanguageID = 1;

    my $Builder;
    eval { $Builder = DE_EPAGES::Presentation::API::Object::TrayBuilder->new( {} ); };
    ok( ExistsError(), 'constructor - no parameter -> fail ' );

    $Builder = DE_EPAGES::Presentation::API::Object::TrayBuilder->new( {
            LanguageID         => $LanguageID,
            TranslationPackage => 'DE_EPAGES::Presentation'
        }
    );
    isa_ok( $Builder, 'DE_EPAGES::Presentation::API::Object::TrayBuilder' );

    # $Id, $IsSelectable, $IsSortable, $IsLinkable, $IsRightAligned, $TranslationKey
    $Builder->addColumnHeader( 'one', [1, 1, 0, 0], 'Customer' )
            ->addColumnHeader( 'two', [1, 0, 0, 0], 'Product' )
            ->addColumnHeader( 'three', [0, 0, 1, 1], 'Name', 'DE_EPAGES::Dictionary' ); # Overwrite lookup dictionary

    my $aHeader = $Builder->getHeaderList();

    is_deeply( $aHeader, ExpectedHeader(), 'column header with translated name' );
}

sub ExpectedHeader {
    return [ {
            'isSortable'   => 1,
            'name'         => 'Kunde',
            'id'           => 'one',
            'isSelectable' => 1,
            'isLinkable'   => 0,
            'isRightAligned' => 0,

        }, {
            'isSortable'   => 0,
            'name'         => 'Produkt',
            'id'           => 'two',
            'isSelectable' => 1,
            'isLinkable'   => 0,
            'isRightAligned' => 0,
        }, {
            'isSortable'   => 0,
            'name'         => 'Name',
            'id'           => 'three',
            'isSelectable' => 0,
            'isLinkable'   => 1,
            'isRightAligned' => 1,
        }
    ];

}

__PACKAGE__->runScript;
1;
